/****************************************************************************
** Meta object code from reading C++ file 'unionidwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../unionidwidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'unionidwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13UnionIDWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto UnionIDWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13UnionIDWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UnionIDWidget",
        "verifyVerficationCodeFinished",
        "",
        "pageChanged",
        "isResetPasswordPage",
        "requestAsyncBindCheck",
        "requestAsyncVerficationCode",
        "phoneEmail",
        "requestVerifyVerficationCode",
        "code",
        "onBindCheckUbidReplied",
        "onBindCheckReplied",
        "onVerficationCodeCountReplied",
        "onRequestVerficationCodeReplied",
        "ret",
        "onRequestVerifyVerficationCodeReplied",
        "onPhoneEmailLineEditFocusChanged",
        "onVerificationCodeBtnClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'verifyVerficationCodeFinished'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'pageChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'requestAsyncBindCheck'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestAsyncVerficationCode'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'requestVerifyVerficationCode'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'onBindCheckUbidReplied'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'onBindCheckReplied'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'onVerficationCodeCountReplied'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'onRequestVerficationCodeReplied'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'onRequestVerifyVerficationCodeReplied'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'onPhoneEmailLineEditFocusChanged'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onVerificationCodeBtnClicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UnionIDWidget, qt_meta_tag_ZN13UnionIDWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UnionIDWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UnionIDWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UnionIDWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13UnionIDWidgetE_t>.metaTypes,
    nullptr
} };

void UnionIDWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UnionIDWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->verifyVerficationCodeFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->pageChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->requestAsyncBindCheck(); break;
        case 3: _t->requestAsyncVerficationCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->requestVerifyVerficationCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->onBindCheckUbidReplied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->onBindCheckReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->onVerficationCodeCountReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->onRequestVerficationCodeReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->onRequestVerifyVerficationCodeReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->onPhoneEmailLineEditFocusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onVerificationCodeBtnClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UnionIDWidget::*)(int )>(_a, &UnionIDWidget::verifyVerficationCodeFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UnionIDWidget::*)(bool )>(_a, &UnionIDWidget::pageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UnionIDWidget::*)()>(_a, &UnionIDWidget::requestAsyncBindCheck, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UnionIDWidget::*)(const QString & )>(_a, &UnionIDWidget::requestAsyncVerficationCode, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UnionIDWidget::*)(const QString & , const QString & )>(_a, &UnionIDWidget::requestVerifyVerficationCode, 4))
            return;
    }
}

const QMetaObject *UnionIDWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UnionIDWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UnionIDWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UnionIDWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void UnionIDWidget::verifyVerficationCodeFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UnionIDWidget::pageChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UnionIDWidget::requestAsyncBindCheck()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UnionIDWidget::requestAsyncVerficationCode(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UnionIDWidget::requestVerifyVerficationCode(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
