// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef UTILS_H
#define UTILS_H

#include <QLocale>
#include <QSettings>
#include <QString>
#include <iostream>
#include <utility>

const std::pair<QString, QString> GetSystemVersion();  // namespace utils

#endif  // UTILS_H
