/****************************************************************************
** Meta object code from reading C++ file 'resetpasswordworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../resetpasswordworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resetpasswordworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19ResetPasswordWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto ResetPasswordWorker::qt_create_metaobjectdata<qt_meta_tag_ZN19ResetPasswordWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResetPasswordWorker",
        "getSecurityQuestionsReplied",
        "",
        "QList<int>",
        "securityQuestions",
        "verifySecretQuestionsReplied",
        "requestBindCheckUbidReplied",
        "ubid",
        "requestBindCheckReplied",
        "result",
        "requestVerficationCodeCountReplied",
        "count",
        "requestVerficationCodeReplied",
        "requestVerifyVerficationCodeReplied",
        "getSecurityQuestions",
        "setPasswordHint",
        "passwordHint",
        "verifySecretQuestions",
        "QMap<int,QString>",
        "asyncBindCheck",
        "asyncRequestVerficationCode",
        "phoneEmail",
        "verifyVerficationCode",
        "code"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'getSecurityQuestionsReplied'
        QtMocHelpers::SignalData<void(const QList<int>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'verifySecretQuestionsReplied'
        QtMocHelpers::SignalData<void(const QList<int>)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestBindCheckUbidReplied'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'requestBindCheckReplied'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'requestVerficationCodeCountReplied'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'requestVerficationCodeReplied'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'requestVerifyVerficationCodeReplied'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'getSecurityQuestions'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPasswordHint'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'verifySecretQuestions'
        QtMocHelpers::SlotData<void(const QMap<int,QString> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 4 },
        }}),
        // Slot 'asyncBindCheck'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'asyncRequestVerficationCode'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'verifyVerficationCode'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResetPasswordWorker, qt_meta_tag_ZN19ResetPasswordWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResetPasswordWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ResetPasswordWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ResetPasswordWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ResetPasswordWorkerE_t>.metaTypes,
    nullptr
} };

void ResetPasswordWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResetPasswordWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->getSecurityQuestionsReplied((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 1: _t->verifySecretQuestionsReplied((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 2: _t->requestBindCheckUbidReplied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->requestBindCheckReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->requestVerficationCodeCountReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->requestVerficationCodeReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->requestVerifyVerficationCodeReplied((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->getSecurityQuestions(); break;
        case 8: _t->setPasswordHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->verifySecretQuestions((*reinterpret_cast<std::add_pointer_t<QMap<int,QString>>>(_a[1]))); break;
        case 10: _t->asyncBindCheck(); break;
        case 11: _t->asyncRequestVerficationCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->verifyVerficationCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(const QList<int> )>(_a, &ResetPasswordWorker::getSecurityQuestionsReplied, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(const QList<int> )>(_a, &ResetPasswordWorker::verifySecretQuestionsReplied, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(const QString & )>(_a, &ResetPasswordWorker::requestBindCheckUbidReplied, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(int )>(_a, &ResetPasswordWorker::requestBindCheckReplied, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(int )>(_a, &ResetPasswordWorker::requestVerficationCodeCountReplied, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(int )>(_a, &ResetPasswordWorker::requestVerficationCodeReplied, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResetPasswordWorker::*)(int )>(_a, &ResetPasswordWorker::requestVerifyVerficationCodeReplied, 6))
            return;
    }
}

const QMetaObject *ResetPasswordWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResetPasswordWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ResetPasswordWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ResetPasswordWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ResetPasswordWorker::getSecurityQuestionsReplied(const QList<int> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ResetPasswordWorker::verifySecretQuestionsReplied(const QList<int> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ResetPasswordWorker::requestBindCheckUbidReplied(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ResetPasswordWorker::requestBindCheckReplied(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ResetPasswordWorker::requestVerficationCodeCountReplied(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ResetPasswordWorker::requestVerficationCodeReplied(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ResetPasswordWorker::requestVerifyVerficationCodeReplied(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
