/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p org_deepin_dde_gesture1 /build/deepin-session-ui/src/dde-session-ui/xml/org.deepin.dde.Gesture1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_DEEPIN_DDE_GESTURE1_H
#define ORG_DEEPIN_DDE_GESTURE1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.Gesture1
 */
class __OrgDeepinDdeGesture1InterfacePrivate;
class __OrgDeepinDdeGesture1Interface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Gesture1"; }

public:
    explicit __OrgDeepinDdeGesture1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__OrgDeepinDdeGesture1Interface();

public Q_SLOTS: // METHODS

Q_SIGNALS: // SIGNALS
    void TouchEdgeEvent(const QString &direction, double scalex, double scaley);
    void TouchMoving(double scalex, double scaley);
    void TouchPressTimeout(int fingers, int time, double scalex, double scaley);
    void TouchSinglePressTimeout(int time, double scalex, double scaley);
    void TouchUpOrCancel(double scalex, double scaley);
    // begin property changed signals

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);

private:
    __OrgDeepinDdeGesture1InterfacePrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__OrgDeepinDdeGesture1Interface Gesture1;
    }
  }
}
#endif
